@@ -6,6 +6,7 @@ from functools import reduce
 from math import floor
 from string import ascii_lowercase, digits
 from typing import Any, Dict, List, Optional, Pattern
+from unicodedata import normalize
 
 from beets import __version__ as beets_version
 from beets.autotag.hooks import AlbumInfo, TrackInfo
@@ -22,7 +23,11 @@ JSONDict = Dict[str, Any]
 
 OFFICIAL = "Official"
 PROMO = "Promotional"
-COUNTRY_OVERRIDES = {"UK": "GB"}
+COUNTRY_OVERRIDES = {
+    "Russia": "RU",  # pycountry: Russian Federation
+    "The Netherlands": "NL",  # pycountry: Netherlands
+    "UK": "GB",  # pycountry: Great Britain
+}
 DATE_FORMAT = "%d %B %Y"
 DATA_SOURCE = "bandcamp"
 DEFAULT_COUNTRY = "XW"
@@ -35,26 +40,26 @@ MEDIA_MAP = {
 }
 VALID_URL_CHARS = {*ascii_lowercase, *digits}
 
-_catalognum = r"([^\d\W]+[_\W]?\d+(?:\W\d|CD)?)"
+_catalognum = r"([^\d\W]+[_\W]?\d{2,}(?:\W\d|CD)?)"
 PATTERNS: Dict[str, Pattern] = {
     "meta": re.compile(r".*datePublished.*", flags=re.MULTILINE),
     "quick_catalognum": re.compile(rf"\[{_catalognum}\]"),
     "catalognum": re.compile(rf"^{_catalognum}|{_catalognum}$"),
     "catalognum_exclude": re.compile(
-        r"vol(ume)?|artists?|2020|2021|(^|[\s])C[\d][\d]", flags=re.IGNORECASE
+        r"vol(ume)?|artists?|2020|2021|(^|\s)C\d\d|\d+/\d+", flags=re.IGNORECASE
     ),
     "country": re.compile(r'location\ssecondaryText">(?:[\w\s]*, )?([\w\s,]+){1,4}'),
     "digital": re.compile(
-        r"(^DIGI ([\d]+\.\s?)?)|(?i:\s?[\[(]digi(tal)? (bonus|only)[\])])"
+        r"(^DIGI ([\d]+\.\s?)?)|(?i:\s?[\[(].*digi(tal)? (bonus|only|exclusive)[\])])"
     ),
     "label": re.compile(r'og:site_name".*content="([^"]*)"'),
     "lyrics": re.compile(r'"lyrics":({[^}]*})'),
     "release_date": re.compile(r"release[ds] ([\d]{2} [A-Z][a-z]+ [\d]{4})"),
     "track_name": re.compile(
         r"""
-((?P<track_alt>[ABCDEFGH]{1,3}\d\d?)[^\w]*)?
-(\s?(?P<artist>[^-]*[^ ])[^a-z]-\s?)?
-(?P<title>([\w]*-[\w])*[^-]*$)""",
+((?P<track_alt>(^[ABCDEFGH]{1,3}\d|^\d)\d?)\s?[.-][^\w]*)?
+(\s?(?P<artist>[^-]*)(\s-\s))?
+(?P<title>(\b([^\s]-|-[^\s]|[^-])+$))""",
         re.VERBOSE,
     ),
     "vinyl_name": re.compile(
@@ -89,7 +94,10 @@ class Helpers:
     @staticmethod
     def parse_track_name(name: str) -> JSONDict:
         match = re.search(PATTERNS["track_name"], name)
-        track: JSONDict = match.groupdict()  # type: ignore
+        try:
+            track = match.groupdict()
+        except AttributeError:
+            track = {"title": name, "artist": None, "track_alt": None}
         title = track["title"]
         excl_digi_only_title = re.sub(PATTERNS["digital"], "", title)
         if excl_digi_only_title != title:
@@ -117,6 +125,13 @@ class Helpers:
         match = re.search(PATTERNS["release_date"], string)
         return match.groups()[0] if match else ""
 
+    @staticmethod
+    def get_duration(source: JSONDict) -> int:
+        for item in source.get("additionalProperty", []):
+            if item.get("name") == "duration_secs":
+                return floor(item.get("value", 0))
+        return 0
+
 
 class Metaguru(Helpers):
     html: str
@@ -187,11 +202,14 @@ class Metaguru(Helpers):
     @property
     def country(self) -> str:
         country = self._search(PATTERNS["country"])
+        ascii_name = normalize("NFKD", country).encode("ascii", "ignore").decode()
         try:
             return (
                 COUNTRY_OVERRIDES.get(country)
-                or getattr(countries.get(name=country, default=object), "alpha_2", None)
-                or subdivisions.lookup(country).country_code
+                or getattr(
+                    countries.get(name=ascii_name, default=object), "alpha_2", None
+                )
+                or subdivisions.lookup(ascii_name).country_code
             )
         except LookupError:
             return DEFAULT_COUNTRY
@@ -224,7 +242,13 @@ class Metaguru(Helpers):
             "@type": ["MusicRecording"],
             "name": "A1 - SMFORMA - Giliau nei garsas",
             "duration": "P00H04M43S"
-            "duration_secs": 283,
+            "additionalProperty": [
+                {"@type": "PropertyValue", "name": "track_id", "value": 1867729685},
+                {"@type": "PropertyValue", "name": "duration_secs", "value": 222.162},
+                {"@type": "PropertyValue", "name": "file", "value": {"mp3-128": "...."}},
+                {"@type": "PropertyValue", "name": "streaming", "value": true},
+                {"@type": "PropertyValue", "name": "tracknum", "value": 2}
+            ],
         },
         """
         tracks = []
@@ -242,7 +266,9 @@ class Metaguru(Helpers):
             for t in self.tracks
         }
         unique_artists.discard(None)
-        if "ep" in self.disctitle.lower() or len(unique_artists) <= 1:
+        if any(
+            ("EP" in self.disctitle, "EP" in self.album_name, len(unique_artists) <= 1)
+        ):
             return True
         return False
 
@@ -262,7 +288,7 @@ class Metaguru(Helpers):
     def albumartist(self) -> str:
         if self.is_va:
             return "Various Artists"
-        if self.is_single_artist and self.tracks and self.tracks[0]["artist"]:
+        if self.is_single_artist and self.tracks and self.tracks[0].get("artist"):
             return self.tracks[0]["artist"]
         return self.bandcamp_albumartist
 
@@ -272,7 +298,7 @@ class Metaguru(Helpers):
             return "album"
         if self.is_va:
             return "compilation"
-        if self.catalognum:
+        if self.catalognum or "EP" in self.disctitle or "EP" in self.album_name:
             return "ep"
         return "album"
 
@@ -283,7 +309,7 @@ class Metaguru(Helpers):
             "data_source": DATA_SOURCE,
             "data_url": self.album_id,
             "index": track.get("position"),
-            "length": floor(track.get("duration_secs", 0)),
+            "length": self.get_duration(track),
             "media": self.media or DEFAULT_MEDIA,
             "track_alt": track.get("track_alt"),
             "disctitle": self.disctitle,
@@ -304,7 +330,7 @@ class Metaguru(Helpers):
             "data_source": DATA_SOURCE,
             "data_url": self.album_id,
             "index": 1,
-            "length": floor(self.meta.get("duration_secs", 0)),
+            "length": self.get_duration(self.meta),
             "media": self.media or DEFAULT_MEDIA,
             "track_alt": track.get("track_alt"),
         }
